summaryrefslogtreecommitdiffstats
path: root/src/H5F.c
diff options
context:
space:
mode:
authorMohamad Chaarawi <chaarawi@hdfgroup.org>2012-03-07 15:05:24 (GMT)
committerMohamad Chaarawi <chaarawi@hdfgroup.org>2012-03-07 15:05:24 (GMT)
commitc7b3e19329bb9f417b397d945c20b27c56a7420f (patch)
treec362eeafee075a301b449d0f93a42eeff0457b17 /src/H5F.c
parenta318d2846c5e6f5cef635c8aa1e54d004aa33ff7 (diff)
parent5ee3764068f93cab6ab9518a8b0ff64ee5d62178 (diff)
downloadhdf5-c7b3e19329bb9f417b397d945c20b27c56a7420f.zip
hdf5-c7b3e19329bb9f417b397d945c20b27c56a7420f.tar.gz
hdf5-c7b3e19329bb9f417b397d945c20b27c56a7420f.tar.bz2
[svn-r22034] merge from trunk r 22032
Diffstat (limited to 'src/H5F.c')
-rw-r--r--src/H5F.c122
1 files changed, 61 insertions, 61 deletions
diff --git a/src/H5F.c b/src/H5F.c
index c81b034..459dbd8 100644
--- a/src/H5F.c
+++ b/src/H5F.c
@@ -89,7 +89,7 @@ H5F_init(void)
{
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_NOAPI(H5F_init, FAIL)
+ FUNC_ENTER_NOAPI(FAIL)
/* FUNC_ENTER() does all the work */
done:
@@ -115,7 +115,7 @@ H5F_init_interface(void)
{
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_NOAPI_NOINIT(H5F_init_interface)
+ FUNC_ENTER_NOAPI_NOINIT
/*
* Initialize the atom group for the file IDs.
@@ -151,7 +151,7 @@ H5F_term_interface(void)
{
int n = 0;
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_term_interface)
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
if(H5_interface_initialize_g) {
if((n = H5I_nmembers(H5I_FILE)) != 0) {
@@ -190,7 +190,7 @@ H5Fget_create_plist(hid_t uid)
{
hid_t ret_value; /* Return value */
- FUNC_ENTER_API(H5Fget_create_plist, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE1("i", "i", uid);
if(H5VL_get(uid, H5F_GET_FCPL, &ret_value, 0, NULL) < 0)
@@ -227,7 +227,7 @@ H5Fget_access_plist(hid_t uid)
{
hid_t ret_value; /* Return value */
- FUNC_ENTER_API(H5Fget_access_plist, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE1("i", "i", uid);
if(H5VL_get(uid, H5F_GET_FAPL, &ret_value, 0, NULL) < 0)
@@ -270,7 +270,7 @@ H5F_get_access_plist(H5F_t *f, hbool_t app_ref)
unsigned efc_size = 0;
hid_t ret_value = SUCCEED;
- FUNC_ENTER_NOAPI(H5F_get_access_plist, FAIL)
+ FUNC_ENTER_NOAPI(FAIL)
/* Check args */
HDassert(f);
@@ -380,7 +380,7 @@ H5Fget_obj_count(hid_t uid, unsigned types)
hid_t id;
ssize_t ret_value; /* Return value */
- FUNC_ENTER_API(H5Fget_obj_count, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE2("Zs", "iIu", uid, types);
if (H5I_UID == H5I_get_type(uid)) {
@@ -430,7 +430,7 @@ H5F_get_obj_count(const H5F_t *f, unsigned types, hbool_t app_ref)
{
size_t ret_value; /* Return value */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_get_obj_count)
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
/* H5F_get_objects doesn't fail */
ret_value = H5F_get_objects(f, types, 0, NULL, app_ref);
@@ -465,7 +465,7 @@ H5Fget_obj_ids(hid_t uid, unsigned types, size_t max_objs, hid_t *oid_list)
hid_t id;
ssize_t ret_value; /* Return value */
- FUNC_ENTER_API(H5Fget_obj_ids, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE4("Zs", "iIuz*i", uid, types, max_objs, oid_list);
if (H5I_UID == H5I_get_type(uid)) {
@@ -517,7 +517,7 @@ H5F_get_obj_ids(const H5F_t *f, unsigned types, size_t max_objs, hid_t *oid_list
{
size_t ret_value; /* Return value */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_get_obj_ids)
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
/* H5F_get_objects doesn't fail */
ret_value = H5F_get_objects(f, types, max_objs, oid_list, app_ref);
@@ -546,7 +546,7 @@ H5F_get_objects(const H5F_t *f, unsigned types, size_t max_index, hid_t *obj_id_
H5F_olist_t olist; /* Structure to hold search results */
size_t ret_value; /* Return value */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_get_objects)
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
/* Set up search information */
olist.obj_id_list = (max_index==0 ? NULL : obj_id_list);
@@ -630,7 +630,7 @@ H5F_get_objects_cb(void *obj_ptr, hid_t obj_id, void *key)
H5F_olist_t *olist = (H5F_olist_t *)key; /* Alias for search info */
int ret_value = FALSE; /* Return value */
- FUNC_ENTER_NOAPI_NOINIT(H5F_get_objects_cb)
+ FUNC_ENTER_NOAPI_NOINIT
HDassert(obj_ptr);
HDassert(olist);
@@ -751,7 +751,7 @@ H5Fget_vfd_handle(hid_t uid, hid_t fapl, void **file_handle)
{
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_API(H5Fget_vfd_handle, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE3("e", "ii**x", uid, fapl, file_handle);
/* Check args */
@@ -792,7 +792,7 @@ H5Fis_hdf5(const char *name)
H5FD_t *file = NULL; /* Low-level file struct */
htri_t ret_value; /* Return value */
- FUNC_ENTER_API(H5Fis_hdf5, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE1("t", "*s", name);
/* Check args and all the boring stuff. */
@@ -843,7 +843,7 @@ H5F_new(H5F_file_t *shared, hid_t fcpl_id, hid_t fapl_id, H5FD_t *lf)
{
H5F_t *f = NULL, *ret_value;
- FUNC_ENTER_NOAPI_NOINIT(H5F_new)
+ FUNC_ENTER_NOAPI_NOINIT
if(NULL == (f = H5FL_CALLOC(H5F_t)))
HGOTO_ERROR(H5E_FILE, H5E_NOSPACE, NULL, "can't allocate top file structure")
@@ -1004,7 +1004,7 @@ H5F_dest(H5F_t *f, hid_t dxpl_id, hbool_t flush)
{
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_NOAPI_NOINIT(H5F_dest)
+ FUNC_ENTER_NOAPI_NOINIT
/* Sanity check */
HDassert(f);
@@ -1190,7 +1190,7 @@ H5F_open(const char *name, unsigned flags, hid_t fcpl_id, hid_t fapl_id,
H5F_close_degree_t fc_degree; /*file close degree */
H5F_t *ret_value; /*actual return value */
- FUNC_ENTER_NOAPI(H5F_open, NULL)
+ FUNC_ENTER_NOAPI(NULL)
/*
* If the driver has a `cmp' method then the driver is capable of
@@ -1410,7 +1410,7 @@ H5Fcreate(const char *filename, unsigned flags, hid_t fcpl_id, hid_t fapl_id)
{
hid_t ret_value; /*return value */
- FUNC_ENTER_API(H5Fcreate, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE4("i", "*sIuii", filename, flags, fcpl_id, fapl_id);
/* Check/fix arguments */
@@ -1504,7 +1504,7 @@ H5Fopen(const char *filename, unsigned flags, hid_t fapl_id)
{
hid_t ret_value; /*return value */
- FUNC_ENTER_API(H5Fopen, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE3("i", "*sIui", filename, flags, fapl_id);
/* Check/fix arguments. */
@@ -1559,7 +1559,7 @@ H5Fflush(hid_t object_id, H5F_scope_t scope)
{
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_API(H5Fflush, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE2("e", "iFs", object_id, scope);
if((ret_value = H5VL_flush(object_id, scope)) < 0)
@@ -1588,7 +1588,7 @@ H5F_flush(H5F_t *f, hid_t dxpl_id, hbool_t closing)
{
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_NOAPI(H5F_flush, FAIL)
+ FUNC_ENTER_NOAPI(FAIL)
/* Sanity check arguments */
HDassert(f);
@@ -1657,7 +1657,7 @@ H5F_close(H5F_t *f)
{
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_NOAPI_NOINIT(H5F_close)
+ FUNC_ENTER_NOAPI_NOINIT
/* Sanity check */
HDassert(f);
@@ -1717,7 +1717,7 @@ H5F_try_close(H5F_t *f)
unsigned nopen_objs = 0; /* Number of open objects in file/mount hierarchy */
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_NOAPI_NOINIT(H5F_try_close)
+ FUNC_ENTER_NOAPI_NOINIT
/* Sanity check */
HDassert(f);
@@ -1874,7 +1874,7 @@ H5Fclose(hid_t file_id)
{
herr_t ret_value = SUCCEED;
- FUNC_ENTER_API(H5Fclose, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE1("e", "i", file_id);
/* Close the file */
@@ -1916,7 +1916,7 @@ H5Freopen(hid_t uid)
H5I_t *uid_info, *new_uid_info;
hid_t file_id, new_file_id, ret_value;
- FUNC_ENTER_API(H5Freopen, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE1("i", "i", file_id);
/* Get the file */
@@ -1985,7 +1985,7 @@ H5Fget_intent(hid_t uid, unsigned *intent_flags)
{
herr_t ret_value = SUCCEED;
- FUNC_ENTER_API(H5Fget_intent, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE2("e", "i*Iu", uid, intent_flags);
/* If no intent flags were passed in, exit quietly */
@@ -2017,7 +2017,7 @@ H5F_get_id(H5F_t *file, hbool_t app_ref)
{
hid_t ret_value;
- FUNC_ENTER_NOAPI_NOINIT(H5F_get_id)
+ FUNC_ENTER_NOAPI_NOINIT
HDassert(file);
@@ -2056,8 +2056,8 @@ done:
unsigned
H5F_incr_nopen_objs(H5F_t *f)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_incr_nopen_objs)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(f);
@@ -2083,8 +2083,8 @@ H5F_incr_nopen_objs(H5F_t *f)
unsigned
H5F_decr_nopen_objs(H5F_t *f)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_decr_nopen_objs)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(f);
@@ -2114,7 +2114,7 @@ H5F_build_actual_name(const H5F_t *f, const H5P_genplist_t *fapl, const char *na
hid_t new_fapl_id = -1; /* ID for duplicated FAPL */
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_NOAPI_NOINIT(H5F_build_actual_name)
+ FUNC_ENTER_NOAPI_NOINIT
/* Sanity check */
HDassert(f);
@@ -2224,8 +2224,8 @@ H5F_addr_encode_len(size_t addr_len, uint8_t **pp/*in,out*/, haddr_t addr)
{
unsigned u; /* Local index variable */
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_addr_encode_len)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(addr_len);
HDassert(pp && *pp);
@@ -2263,8 +2263,8 @@ H5F_addr_encode_len(size_t addr_len, uint8_t **pp/*in,out*/, haddr_t addr)
void
H5F_addr_encode(const H5F_t *f, uint8_t **pp/*in,out*/, haddr_t addr)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_addr_encode)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(f);
@@ -2297,8 +2297,8 @@ H5F_addr_decode_len(size_t addr_len, const uint8_t **pp/*in,out*/, haddr_t *addr
hbool_t all_zero = TRUE; /* True if address was all zeroes */
unsigned u; /* Local index variable */
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_addr_decode_len)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(addr_len);
HDassert(pp && *pp);
@@ -2362,8 +2362,8 @@ H5F_addr_decode_len(size_t addr_len, const uint8_t **pp/*in,out*/, haddr_t *addr
void
H5F_addr_decode(const H5F_t *f, const uint8_t **pp/*in,out*/, haddr_t *addr_p/*out*/)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_addr_decode)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(f);
@@ -2392,7 +2392,7 @@ H5Fget_freespace(hid_t uid)
{
hssize_t ret_value; /* Return value */
- FUNC_ENTER_API(H5Fget_freespace, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE1("Hs", "i", uid);
if(H5VL_get(uid, H5F_GET_FREE_SPACE, &ret_value, 0, NULL) < 0)
@@ -2426,7 +2426,7 @@ H5Fget_filesize(hid_t uid, hsize_t *size)
{
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_API(H5Fget_filesize, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE2("e", "i*h", uid, size);
if((ret_value = H5VL_get(uid, H5F_GET_SIZE, (void *)size, 0, NULL)) < 0)
@@ -2460,7 +2460,7 @@ H5Fget_mdc_config(hid_t uid, H5AC_cache_config_t *config_ptr)
{
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_API(H5Fget_mdc_config, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE2("e", "i*x", uid, config_ptr);
/* check args */
@@ -2497,7 +2497,7 @@ H5Fset_mdc_config(hid_t uid, H5AC_cache_config_t *config_ptr)
H5I_t *uid_info; /* user id structure */
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_API(H5Fset_mdc_config, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE2("e", "i*x", uid, config_ptr);
if(H5I_UID != H5I_get_type(uid))
@@ -2539,7 +2539,7 @@ H5Fget_mdc_hit_rate(hid_t uid, double *hit_rate_ptr)
{
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_API(H5Fget_mdc_hit_rate, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE2("e", "i*d", uid, hit_rate_ptr);
if(NULL == hit_rate_ptr)
@@ -2577,7 +2577,7 @@ H5Fget_mdc_size(hid_t uid, size_t *max_size_ptr, size_t *min_clean_size_ptr,
void *argv[3];
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_API(H5Fget_mdc_size, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE5("e", "i*z*z*z*Is", uid, max_size_ptr, min_clean_size_ptr,
cur_size_ptr, cur_num_entries_ptr);
@@ -2619,7 +2619,7 @@ H5Freset_mdc_hit_rate_stats(hid_t uid)
H5I_t *uid_info; /* user id structure */
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_API(H5Freset_mdc_hit_rate_stats, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE1("e", "i", uid);
if(H5I_UID != H5I_get_type(uid))
@@ -2668,7 +2668,7 @@ H5Fget_name(hid_t uid, char *name/*out*/, size_t size)
void *argv[2]; /* arguments to the VOL callback */
ssize_t ret_value;
- FUNC_ENTER_API (H5Fget_name, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE3("Zs", "ixz", uid, name, size);
argv[0] = &ret_value;
@@ -2703,7 +2703,7 @@ H5Fget_info2(hid_t uid, H5F_info2_t *finfo)
{
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_API(H5Fget_info2, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE2("e", "i*x", uid, finfo);
/* Check args */
@@ -2739,7 +2739,7 @@ H5Fget_free_sections(hid_t uid, H5F_mem_t type, size_t nsects,
void *argv[3];
ssize_t ret_value; /* Return value */
- FUNC_ENTER_API(H5Fget_free_sections, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE4("Zs", "iFmzx", uid, type, nsects, sect_info);
/* Check args */
@@ -2778,7 +2778,7 @@ H5Fclear_elink_file_cache(hid_t uid)
H5I_t *uid_info; /* user id structure */
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_API(H5Fclear_elink_file_cache, FAIL)
+ FUNC_ENTER_API(FAIL)
H5TRACE1("e", "i", uid);
/* Check args */
@@ -2816,8 +2816,8 @@ done:
herr_t
H5F_set_grp_btree_shared(H5F_t *f, H5RC_t *rc)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_set_grp_btree_shared)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
/* Sanity check */
HDassert(f);
@@ -2846,8 +2846,8 @@ H5F_set_grp_btree_shared(H5F_t *f, H5RC_t *rc)
herr_t
H5F_set_sohm_addr(H5F_t *f, haddr_t addr)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_set_sohm_addr)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
/* Sanity check */
HDassert(f);
@@ -2875,8 +2875,8 @@ H5F_set_sohm_addr(H5F_t *f, haddr_t addr)
herr_t
H5F_set_sohm_vers(H5F_t *f, unsigned vers)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_set_sohm_vers)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
/* Sanity check */
HDassert(f);
@@ -2904,8 +2904,8 @@ H5F_set_sohm_vers(H5F_t *f, unsigned vers)
herr_t
H5F_set_sohm_nindexes(H5F_t *f, unsigned nindexes)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_set_sohm_nindexes)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
/* Sanity check */
HDassert(f);
@@ -2933,8 +2933,8 @@ H5F_set_sohm_nindexes(H5F_t *f, unsigned nindexes)
herr_t
H5F_set_store_msg_crt_idx(H5F_t *f, hbool_t flag)
{
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_set_store_msg_crt_idx)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
/* Sanity check */
HDassert(f);